@@ -109,7 +109,11 @@ format_numbers <- function (string, num_fmt) {
         stop('Unrecognized type of number_format: should be function, character or integer. See ?number_format')
   # Optional minus, then any number of digits followed by an optional decimal point
   # which is assumed to be "." (?Sys.setlocale suggests this is a reasonable assumption)
-  stringr::str_replace_all(string, '-?\\d+(\\.\\d+)?', function (x) format_numeral(as.numeric(x)))
+  # the first bracketed expression (?<!\\d(e|E)?) is a negative lookbehind assertion
+  # that we don't have a digit followed by e or E i.e. it should avoid formatting exponents
+  # we use 0 or more e/E characters to avoid matching substrings of an exponent e.g.
+  # 5e12 must not match the "12" but should also not match the "2"
+  stringr::str_replace_all(string, '(?<!\\d(e|E)?)-?\\d+(\\.\\d+)?', function (x) format_numeral(as.numeric(x)))
 }
 
 
@@ -458,7 +462,11 @@ NULL
 #' @export
 quick_pdf <- function (..., file = "huxtable-output.pdf", borders = 0.4) {
   hts <- huxtableize(list(...), borders)
-  latex_file <- tempfile(fileext = ".tex")
+  # on my Mac, tempdir() gets a double slash in the path, which screws up texi2pdf.
+  # You can't use normalizePath with a non-existent file, so the below doesn't work:
+  # latex_file <- normalizePath(tempfile(fileext = ".tex"), mustWork = TRUE)
+  clean_tmp_dir <- normalizePath(tempdir())
+  latex_file <- tempfile(tmpdir = clean_tmp_dir, fileext = ".tex")
   sink(latex_file)
   tryCatch({
       cat('\\documentclass{article}\n')
@@ -474,16 +482,16 @@ quick_pdf <- function (..., file = "huxtable-output.pdf", borders = 0.4) {
     error = identity,
     finally = {sink()}
   )
-  # we do this because using tempfile on its own is fucked up by the double slash.
-  if (! file.copy(latex_file, '.', overwrite = TRUE)) stop('Could not copy tex file to current directory.')
-  latex_file <- basename(latex_file)
-  tools::texi2pdf(latex_file, clean = TRUE)
-  pdf_file <- sub('\\.tex$', '.pdf', latex_file)
-  if (! file.remove(latex_file)) warning('Could not remove intermediate TeX file "', latex_file,
-        '" from current working directory.')
-  if (! file.exists(pdf_file)) stop('Could not find pdf file output from texi2pdf in current working directory.')
-  if (! file.rename(pdf_file, file)) stop('Could not move pdf file to ', file, '. The pdf file remains at "', pdf_file,
-        '" in the current working directory.')
+
+  tools::texi2pdf(latex_file, clean = TRUE) # outputs to current working directory
+  pdf_file <- sub('\\.tex$', '.pdf', basename(latex_file))
+  if (! file.exists(pdf_file)) stop('Could not find texi2pdf output file "', pdf_file, '"')
+  if (! file.remove(latex_file)) warning('Could not remove intermediate TeX file "', latex_file, '"')
+  if (file.copy(pdf_file, file)) {
+    file.remove(pdf_file)
+  } else {
+    stop('Could not copy pdf file to ', file, '. The pdf file remains at "', pdf_file, '"')
+  }
 
   invisible(NULL)
 }
